import math


class Error(Exception):
    """
    Base class for exceptions in this module. All user-defined exceptions should be defined as classes that end
    the suffix Error.
    """

    def __init__(self, value: str = ''):
        if not hasattr(self, 'value'):
            self.value = value

    def __str__(self):
        return repr(self.value)


class InvalidErrorResponseError(Error):
    value = 'A valid status code must be provided.'


def _get_http_status_code(internal_status_code: int):
    """
    Converts internal 5 digit status code to 3 digit http code

    Args:
        internal_status_code: Our internal system of Status code
    Returns:
        A valid http status code value converted from our internal status code, raises exception if invalid value found
    """
    http_status_code = internal_status_code if math.floor(internal_status_code / 100) <= 6 else math.floor(
        internal_status_code / 100
    )

    if not http_status_code:
        raise InvalidErrorResponseError()

    return http_status_code
